import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mBrtadd from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BrtaddScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'brtadd'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mBrtadd()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('brtadd/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]


    //按钮事件
    onSetinstxm_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/setinstxm_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDocdis_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/docdis_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtadd/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">

	
	<Label itext="信用证编号" trn="brtadd" />	
	<InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="信用证余额" trn="brtadd" />	
	<SelectItem InputProps={bind("opn11_cur")} code={CodeTable.cur}  desp="Currency" path="/lidgrp/cbs/opn1/cur"/>
	<InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />

	
	<Label itext="单据参考号" trn="brtadd" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Own Reference BR Number" path="/brdgrp/rec/ownref" />
	<InputItem InputProps={bind("nam")}  maxLength={40}  desp="Name of Bill Contract" path="/brdgrp/rec/nam" />

	
	<Label itext="申请人" trn="brtadd" />	

	
	<Label itext="编号" trn="brtadd" />	
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/apl/pts/ref" />

	
	<Label itext="到期日" trn="brtadd" />	
	<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
	<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/apl/pts/nam" />

	
	<Label itext="单据金额" trn="brtadd" />	
	<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />

	
	<Label itext="受益人" trn="brtadd" />	

	
	<Label itext="编号" trn="brtadd" />	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/ben/pts/ref" />

	
	<Label itext="单据余额" trn="brtadd" />	
	<InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/brdgrp/cbs/opn1/cur" />
	<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/brdgrp/cbs/opn1/amt" />
	<InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/ben/pts/nam" />

	
	<Label itext="到单日期" trn="brtadd" />	
	<DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />

	
	<Label itext="通知到单日期" trn="brtadd" />	
	<DatePickerItem InputProps={bind("advdat")}  desp="Date of Advice of Payment" path="/brdgrp/rec/advdat" />

	
	<Label itext="远期单据到期日" trn="brtadd" />	
	<Label value={this.model.matp_mattxtlab}   desp="Label for MATTXT" path="/brtp/matp/mattxtlab" />
	<DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />

	
	<Label itext="交单行" trn="brtadd" />	

	
	<Label itext="编号" trn="brtadd" />	
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/prb/pts/ref" />
	<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>

	
	<Label itext="单据类型" trn="brtadd" />	
	<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/prb/pts/nam" />

	
	<Label itext="单据状态" trn="brtadd" />	
	<SelectItem InputProps={bind("docsta")} code={CodeTable.docsta}  desp="Document Set Status" path="/brdgrp/rec/docsta"/>

	
	<Label itext="不符点" trn="brtadd" />	
	<CheckboxItem InputProps={bind("igndisflg")}  desp="Ignore Discrepancies" path="/brdgrp/rec/igndisflg" />
	<TextAreaItem InputProps={bind("blk_docdis")} desp="Discrepancies" path="/brdgrp/blk/docdis"/>
	<Button  type="primary" icon="search" onClick={this.onDocdis_buttxmsel} desp="..." path="/brtp/docdis/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<CheckboxItem InputProps={bind("blk_docdisflg")}  desp="discrepancies modified" path="/brdgrp/blk/docdisflg" />

	
	<Label itext="收到的通知类型" trn="brtadd" />	
	<SelectItem InputProps={bind("advtyp")} code={CodeTable.advtyp}  desp="Type of Advice Received" path="/brdgrp/rec/advtyp"/>

	
	<Label itext="注释和结论" trn="brtadd" />	

	
	<Label itext="付款日期" trn="brtadd" />	
	<DatePickerItem InputProps={bind("totdat")}  desp="Date to be Paid" path="/brdgrp/rec/totdat" />
	<TextAreaItem InputProps={bind("blk_comcon")} desp="Comments and Conclusions" path="/brdgrp/blk/comcon"/>

	
	<Label itext="Discrepancy Advice Dated" trn="brtadd" />	
	<DatePickerItem InputProps={bind("disdat")}  desp="Date of Discrepancy Advice" path="/brdgrp/rec/disdat" />
	<CheckboxItem InputProps={bind("approvcod")}  desp="Documents on Approval Basis" path="/brdgrp/rec/approvcod" />

	
	<Label itext="结算指示" trn="brtadd" />	
	<TextAreaItem InputProps={bind("blk_setinsbr")} desp="Settlement Instructions BR" path="/brdgrp/blk/setinsbr"/>
	<Button  type="primary" icon="search" onClick={this.onSetinstxm_buttxmsel} desp="..." path="/brtp/setinstxm/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<Label value={this.model.docgrdm_docdsclab}   desp="Label of document description" path="/brtp/docgrdm/docdsclab" />
	<CheckboxItem InputProps={bind("brtp_cre752flg")}  desp="Create 752" path="/brtp/cre752flg" />

	
	<Label itext="Further Identification" trn="brtadd" />	
	<SelectItem InputProps={bind("brtp_furide")}   desp="MT752: Further Indentification" path="/brtp/furide"/>
	<CheckboxItem InputProps={bind("brtp_cre732flg")}  desp="Create MT 732" path="/brtp/cre732flg" />

	
	<Label itext="会计分录" trn="brtadd" />	
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>

	
	<Label itext="面函码值" trn="brtadd" />	
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />

	
	<Label itext="Per Medium" trn="brtadd" />	
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>

	
	<Label itext="面函路径" trn="brtadd" />	
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>

	
	<Label itext="唯一编号" trn="brtadd" />	
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />

	
	<Label itext="A" trn="brtadd" />	
	<InputItem InputProps={bind("trndoc_doctrestm")}   desp="Document tree" path="/trnmod/trndoc/doctrestm" />
	<Button  type="primary"  onClick={this.onTrndoc_butadd} desp="Details" path="/trnmod/trndoc/butadd">
		<Label   itext="B"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butnew} desp="New Entry" path="/trnmod/trndoc/butnew">
		<Label   itext="C"/>
	</Button>
	<Button  icon="delete" onClick={this.onTrndoc_butdel} desp="Delete Entry" path="/trnmod/trndoc/butdel">
		<Label   itext="D"/>
	</Button>
	<CheckboxItem InputProps={bind("trndoc_shwinc")}  desp="Show Incoming Messages" path="/trnmod/trndoc/shwinc" />
	<CheckboxItem InputProps={bind("trndoc_shwout")}  desp="Show Outgoing Messages" path="/trnmod/trndoc/shwout" />
	<CheckboxItem InputProps={bind("trndoc_shwoutint")}  desp="Show Internal Messages" path="/trnmod/trndoc/shwoutint" />
	<Button  type="primary"  onClick={this.onTrndoc_butatt} desp="Attach" path="/trnmod/trndoc/butatt">
		<Label   itext="E"/>
	</Button>
	<InputItem InputProps={bind("trndoc_condocstm")}   desp="Connected Documents" path="/trnmod/trndoc/condocstm" />
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
		</div>
		)
	}
}
