import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mBrtdck from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import Business from '@/views/Public/Business'
import Ptspta2 from '@/views/Public/Ptspta2'
import {Row,Col} from 'antd'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BrtdckScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'brtdck'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mBrtdck()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('brtdck/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }
	
	//
	onPrbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/prbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
	}
	onOthp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/othp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
				{/* brtp/brthdr */}
				{/* 第1行 */}
				<Business wrappedComponentRef={ref => (this.com = ref)} page={this} extra={this.props.extra} steps={this.props.steps} model={this.model} />

				<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="信用证编号" trn="brtdck" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="信用证余额" trn="brtdck" />	
								</Col>
								<Col span={6}>
									<SelectItem InputProps={bind("opn11_cur")} code={CodeTable.cur}  desp="Currency" path="/lidgrp/cbs/opn1/cur"/>
								</Col>
								<Col span={7} offset={1}>
									<InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第2行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据参考号" trn="brtdck" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Own Reference BR Number" path="/brdgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Name of Bill Contract" trn="brtdck" />	 */}
									<Label itext="N O B C" trn="brtdck" />
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("nam")}  maxLength={40}  desp="Name of Bill Contract" path="/brdgrp/rec/nam" />
								</Col>
								
							</Row>
						</Col>
					</Row>
					{/* 第3行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="申请人" trn="brtdck" />	
								</Col>
							</Row>
							
						</Col>
					
					</Row>
					{/* 第4行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="编号" trn="brtdck" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/apl/pts/ref" />
								</Col>
							</Row>
							
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到期日" trn="brtdck" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
								</Col>
							</Row>
							
						</Col>
                    </Row>
						{/* 第5行 */}
						<Row>
							<Col span={12}>
								<Row className="row">
									<Col span={5} offset={2}>
										<Label itext="客户英文名称" trn="brtdck" />	
									</Col>
									<Col span={14}>
										<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/apl/pts/nam" />
									</Col>
								</Row>
								
							</Col>
							<Col span={12}>
								<Row className="row">
									<Col span={5} offset={2}>
										<Label itext="单据金额" trn="brtdck" />	
									</Col>
									<Col span={6}>
										<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
									</Col>
									<Col span={7} offset={1}>
										<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />
									</Col>
								</Row>
							</Col>
						</Row>
						{/* 第6行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                     <Label itext="受益人" trn="brtdck" />	
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第7行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="编号" trn="brtdck" />	
								</Col>
                                <Col span={14} >
                                 <InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/ben/pts/ref" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="单据余额" trn="brtdck" />	
								</Col>
                                <Col span={6} >
                                     <InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/brdgrp/cbs/opn1/cur" />
								</Col>
                                <Col span={7}  offset={1}>
                                     <InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/brdgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第8行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="客户英文名称" trn="brtdck" />	
								</Col>
                                <Col span={14} >
                                    <InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/ben/pts/nam" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="到单日期" trn="brtdck" />	
								</Col>
                                <Col span={14} >
                                    <DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第9行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="通知到单日期" trn="brtdck" />	
								</Col>
                                <Col span={14} >
                                    <DatePickerItem InputProps={bind("advdat")}  desp="Date of Advice of Payment" path="/brdgrp/rec/advdat" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="远期单据到期日" trn="brtdck" />	
								</Col>
                                <Col span={14} >
                                     <DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第10行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="交单行" trn="brtdck" />	
								</Col>
							</Row>
						</Col>
                    </Row>
                     {/* 第11行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                     <Label itext="编号" trn="brtdck" />	
								</Col>
                                <Col span={14} >
                                    <InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/prb/pts/ref" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                     <Label itext="客户英文名称" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/prb/pts/nam" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第12行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                     <Label itext="单据类型" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
                                    <Label itext="单据状态" trn="brtdck" />	
								</Col>
                                <Col span={14} >
                                    <SelectItem InputProps={bind("docsta")} code={CodeTable.docsta}  desp="Document Set Status" path="/brdgrp/rec/docsta"/>
								</Col>
							</Row>
						</Col>
                    </Row>
					{/* 第13行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
								<Label itext="Document Type" trn="brtdck" />
								</Col>	
                                <Col span={14} >
									<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>							
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
								<Label itext="Document Amount" trn="brtdck" />	
								</Col>
                                <Col span={6} >
									<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
								</Col>
								<Col span={7}  offset={1}>
									<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />
								</Col>
							</Row>
						</Col>
                    </Row>
			{/* brtp/brthdr */}




			 
				
					{/* 第14-17行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Presented by" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<SelectItem InputProps={bind("docprbrol")}   desp="Presented by" path="/brdgrp/rec/docprbrol"/>
								</Col>
							</Row>
							<Row className="row">
								<Col >
                                    <Ptspta2 model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址",prefix: 'pts2', url: 'brtdck/prbp_sel', flg: 'C', datakey: '\\brtp\\prbp\\ptslst' }} formBlur={this.formBlur}/>
                                </Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Payer" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<SelectItem InputProps={bind("payrol")}   desp="Payer" path="/brdgrp/rec/payrol"/>
								</Col>
							</Row>
						
							<Row className="row">
								<Col >
                                    <Ptspta2 model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址",prefix: 'pts3', url: 'brtdck/othp_sel', flg: 'C', datakey: '\\brtp\\othp\\ptslst' }} formBlur={this.formBlur}/>
                                </Col>
							</Row>
						</Col>
                    </Row>
					{/* 第18行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="附加金额" trn="brtdck" />	
								</Col>
                                <Col span={6} >
									<SelectItem InputProps={bind("opn2_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/opn2/cur"/>
								</Col>
								<Col span={7} offset={1} >
									<InputItem InputProps={bind("max2_amt")}   desp="Balance" path="/brdgrp/cbs/max2/amt" />
								</Col>						
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Balance" trn="brtdck" />	
								</Col>
                                <Col span={6} >
									<InputItem InputProps={bind("max21_amt")}   desp="Balance" path="/oldbrdgrp/cbs/max2/amt" />
								</Col>
								
							</Row>
						</Col>
                    </Row>
					{/* 第19行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Presentation Date" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<DatePickerItem InputProps={bind("predat")}  desp="Presentation Date" path="/brdgrp/rec/predat" />
								</Col>					
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Received on" trn="brtdck" />	
								</Col>
                                <Col span={6} >
									<DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />
								</Col>
								
							</Row>
						</Col>
                    </Row>
					{/* 第20行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Maturity Date" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />
								</Col>					
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Shipped on" trn="brtdck" />	
								</Col>
                                <Col span={6} >
									<DatePickerItem InputProps={bind("shpdat")}  desp="Date of Shipment" path="/brdgrp/rec/shpdat" />
								</Col>
								
							</Row>
						</Col>
                    </Row>
					{/* 第21行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Maturity Period" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<TextAreaItem InputProps={bind("blk_matper")} desp="Maturity Period" path="/brdgrp/blk/matper"/>
								</Col>					
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Applicant Reference" trn="brtdck" />	
								</Col>
                                <Col span={6} >
									<InputItem InputProps={bind("aplref")}  maxLength={16}  desp="Applicant Reference" path="/lidgrp/rec/aplref" />
								</Col>
								
							</Row>
						</Col>
                    </Row>
					{/* 第22行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Previous Drawings under this L/C" trn="brtdck" />	 */}
									<Label itext="P Drw Und T L/C" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<InputItem InputProps={bind("utlnbr")}   desp="Count of Received Document Sets" path="/lidgrp/rec/utlnbr" />
								</Col>					
							</Row>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Register to Send and Settle Document" trn="brtdck" />	 */}
									<Label itext="Reg T S A S Doc" trn="brtdck" />	
								</Col>
                                <Col span={14} >
									<CheckboxItem InputProps={bind("brtp_setnowflg")}  desp="Register to Send and Settle Document" path="/brtp/setnowflg" />
								</Col>					
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Enter Docs, Discrep. and Instructions" trn="brtdck" />	 */}
									<Label itext="E D D A Ins" trn="brtdck" />	
								</Col>
                                <Col span={6} >
									<CheckboxItem InputProps={bind("dscinsflg")}  desp="Enter Docs, Discrep. and Instructions" path="/brdgrp/rec/dscinsflg" />
								</Col>
								
							</Row>
						</Col>
                    </Row>


	
	
	{/* <Label value={this.model.oriaddlab}   desp="Label original" path="/oriaddlab" /> */}

	<BottomBtn _this={this} />
	
		</div>
		)
	}
}
