import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mBrtfre from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import { Col, Row } from 'antd'
import Business from '@/views/Public/Business'
import Ptspta2 from '@/views/Public/Ptspta2'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BrtfreScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'brtfre'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mBrtfre()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('brtfre/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

	//
	onTxtfre_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtfre/txtfre_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
	}
	onFmop_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtfre/fmop_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
	}
	onFmcp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtfre/fmcp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
				<Business wrappedComponentRef={ref => (this.com = ref)} page={this} extra={this.props.extra} steps={this.props.steps} model={this.model} />

				{/* 第1行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到日期" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第2行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="信用证余额" trn="brtfre" />	
								</Col>
								<Col span={6}>
									<InputItem InputProps={bind("opn11_cur")}  maxLength={3}  desp="Currency" path="/lidgrp/cbs/opn1/cur" />
								</Col>
								<Col span={7} offset={1}>
									<InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据参考号" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Own Reference BR Number" path="/brdgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第3行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Name of Bill Contract" trn="brtfre" />	 */}
									<Label itext="N O B C" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("nam")}  maxLength={40}  desp="Name of Bill Contract" path="/brdgrp/rec/nam" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据金额" trn="brtfre" />	
								</Col>
								<Col span={6}>
								<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
								</Col>
								<Col span={7} offset={1}>
								<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第4行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
								<Label itext="申请人" trn="brtfre" />	
								</Col>
							</Row>
						</Col>
						
					</Row>
				{/* 第4行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/apl/pts/ref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据余额" trn="brtfre" />	
								</Col>
								<Col span={6}>
									<InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/brdgrp/cbs/opn1/cur" />
								</Col>
								<Col span={7} offset={1}>
									<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/brdgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第5行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="客户英文名称" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/apl/pts/nam" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到单日期" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第6行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="寄单日期" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("advdat")}  desp="Date of Advice of Payment" path="/brdgrp/rec/advdat" />
								</Col>
							</Row>
						</Col>
						
					</Row>
					{/* 第7行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="受益人" trn="brtfre" />	
								</Col>
							</Row>
						</Col>
						
					</Row>
					{/* 第8行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/ben/pts/ref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到期日" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第9行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="客户英文名称" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/ben/pts/nam" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据类型" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第10行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="交单行" trn="brtfre" />	
								</Col>
							</Row>
						</Col>
						
					</Row>
					{/* 第11行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/prb/pts/ref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据承付状态" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("docsta")} code={CodeTable.docsta}  desp="Document Set Status" path="/brdgrp/rec/docsta"/>
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第12行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="客户英文名称" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/prb/pts/nam" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第13-16行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="收报行" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("fremsg_msgrol")} code={CodeTable.rolall}  desp="Role Message" path="/fremsg/msgrol"/>
								</Col>
							</Row>
							<Row className="row">
							<Col >
								<Ptspta2 model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址",prefix: 'pts4', url: 'brtfre/fmop_sel', flg: 'C', datakey: '\\brtp\\fmop\\ptslst' }} formBlur={this.formBlur}/>
							</Col>
							</Row>
						</Col>
						<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="副本的收报行" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("fremsg_ccrol")} code={CodeTable.rolall}  desp="Role Copy" path="/fremsg/ccrol"/>
								</Col>
							</Row>
							<Row className="row">
							<Col >
								<Ptspta2 model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址",prefix: 'pts3', url: 'brtfre/fmcp_sel', flg: 'C', datakey: '\\brtp\\fmcp\\ptslst' }} formBlur={this.formBlur}/>
							</Col>
							</Row>
							
						</Col>
					</Row>
					{/* 第17行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="发报类型" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("fremsg_sndmt")} code={CodeTable.sndmt}  desp="message to be created" path="/fremsg/sndmt"/>
								</Col>
							</Row>
						</Col>
						<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="报文类型" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("fremsg_fulmt")} code={CodeTable.fulmt}  desp="MT to Send" path="/fremsg/fulmt"/>
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第18行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="标题" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("fremsg_prttitle")}  maxLength={35}  desp="Document Title" path="/fremsg/prttitle" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="相关报文" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("fremsg_relmt")} code={CodeTable.relmt}  desp="related MT" path="/fremsg/relmt"/>
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第19行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="relevant message" trn="brtfre" />	
								</Col>
								<Col span={6}>
									<DatePickerItem InputProps={bind("fremsg_reldat")}  desp="from" path="/fremsg/reldat" />
								</Col>
								<Col span={7} offset={1}>
									<SelectItem InputProps={bind("fremsg_reldir")} code={CodeTable.reldir}  desp="relevant message sent/received" path="/fremsg/reldir"/>
								</Col>
							</Row>
						</Col>
						<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="flg for gitfre" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<CheckboxItem InputProps={bind("fremsg_flg")}  desp="flg for gitfre" path="/fremsg/flg" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第20行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="tag 20 Ref" trn="brtfre" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("fremsg_tag20ref")}  maxLength={16}  desp="tag 20 Ref" path="/fremsg/tag20ref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Narrative" trn="brtfre" />	
								</Col>
								<Col span={11}>
									<TextAreaItem InputProps={bind("fremsg_strinf")} desp="Narrative" path="/fremsg/strinf"/>
								</Col>
								<Col span={2} offset={1}>
									<Button  type="primary" icon="search" onClick={this.onTxtfre_buttxmsel} desp="..." path="/fremsg/txtfre/buttxmsel">
										<Label   itext="..."/>
									</Button>								
								</Col>
							</Row>
						</Col>
					</Row>
					
			

	
	
	

	
	{/* <InputItem InputProps={bind("pts4_extkey")}  maxLength={16}  desp="客户编号" path="/fremsg/fmo/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onFmop_sel} desp="查询" path="/fremsg/fmop/sel">
		<Label   itext="查询"/>
	</Button> */}

	
	{/* <TextAreaItem InputProps={bind("pts4_adrblk")} desp="SWIFT地址" path="/fremsg/fmo/pts/adrblk"/> */}

	

	

	
	{/* <InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/fremsg/fmc/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onFmcp_sel} desp="查询" path="/fremsg/fmcp/sel">
		<Label   itext="查询"/>
	</Button> */}
	
	{/* <TextAreaItem InputProps={bind("pts3_adrblk")} desp="SWIFT地址" path="/fremsg/fmc/pts/adrblk"/> */}

	<BottomBtn _this={this} />
	
		</div>
		)
	}
}
