import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem, BottomBtn, DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mGetcan from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import { Row, Col, Card } from 'antd'
import Business from '@/views/Public/Business'

const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class GetcanScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'getcan'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mGetcan()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('getcan/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }



    
    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props

        return(
			<Card title="出口保函注销" size="small" className="transTitle">
            <div style={{position:'relative',backgroundColor:'#fff',height:'100%'}} >
                {/* 第1行 */}
				<Business wrappedComponentRef={ref => (this.com = ref)} extra={this.props.extra} model={this.model} />
                <Row>
                    {/* 第1行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Reference" trn="getcan" />
							</Col>
							<Col span={14}>
                                <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/gidgrp/rec/ownref" />
							</Col>
						</Row>
					</Col>
                    {/* 第1行第2列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Name" trn="getcan" />
							</Col>
							<Col span={14}>
                            <InputItem InputProps={bind("nam")}  maxLength={40}  desp="Externally Displayed Name to Identify the Contract" path="/gidgrp/rec/nam" />
							</Col>
						</Row>
					</Col>
				</Row>

                {/* 第2行 */}
				<Row>
					{/* 第2行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Guarantee Amount" trn="getcan" />
							</Col>
							<Col span={6}>
                                <InputItem InputProps={bind("max_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/max/cur" />
							</Col>
							<Col span={7} offset={1}>
                                <InputItem InputProps={bind("max_amt")}   desp="Balance" path="/gidgrp/cbs/max/amt" />
							</Col>
						</Row>
					</Col>
					{/* 第2行第2列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Applicant" trn="getcan" />	
							</Col>
							<Col span={14}>
                                <InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/apl/pts/nam" />
							</Col>							
						</Row>
					</Col>
				</Row>

                {/* 第3行 */}
                <Row>
                    {/* 第3行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Open Amount" trn="getcan" />
                                <Label value={this.model.gitp0_aplmullab}   desp="Label, that is set, if there are multiple applicants" path="/gitp0/aplmullab" />
							</Col>
							<Col span={6} >
                                <InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/opn1/cur" />
							</Col>
							<Col span={7} offset={1}>
                                <InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/gidgrp/cbs/opn1/amt" />
							</Col>
						</Row>
					</Col>
                    {/* 第3行第2列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
                                <Label itext="Beneficiary" trn="getcan" />	
							</Col>
							<Col span={14}>
                                <InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/ben/pts/nam" />
							</Col>
						</Row>
					</Col>
				</Row>

                {/* 第4行 */}
				<Row>
                    {/* 第4行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
                                <Label itext="Handling Type" trn="getcan" />
							</Col>
							<Col span={14}>
                                <SelectItem InputProps={bind("hndtyp")} code={CodeTable.hndtyp}  desp="Handling Type" path="/gidgrp/rec/hndtyp"/>
							</Col>
						</Row>
					</Col>
                    {/* 第4行第2列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
                                <Label itext="Adv\Rcv Bank" trn="getcan" />	
							</Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/adv/pts/nam" />
							</Col>
						</Row>
					</Col>
					
				</Row>

                {/* 第5行 */}
				<Row>
					{/* 第5行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Type of Undertaking" trn="getcan" />
							</Col>
							<Col span={14} >
                                <SelectItem InputProps={bind("gartyp")} code={CodeTable.typgar}  desp="Type of Undertaking" path="/gidgrp/rec/gartyp"/>
							</Col>
						</Row>
					</Col>
					{/* 第5行第2列 */}
                    <Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Issuing Bank" trn="getcan" />
							</Col>
							<Col span={14}>
                                <InputItem InputProps={bind("pts3_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/iss/pts/nam" />
							</Col>
						</Row>
					</Col>
				</Row>
				

				{/* 第6行 */}
				<Row>
                    {/* 第6行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="expfldlab" trn="getcan" />
							</Col>
							<Col span={14}>
								<DatePickerItem InputProps={bind("expdat")}  desp="Valid until" path="/gidgrp/rec/expdat" />
								<Label value={this.model.gitp0_expfldlab}   desp="Label for Field Validity" path="/gitp0/expfldlab" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
							<Label itext="liafldlab" trn="getcan" />							</Col>
							<Col span={14}>
								<DatePickerItem InputProps={bind("liadat")}  desp="Liability until" path="/gidgrp/rec/liadat" />
								<Label value={this.model.gitp0_liafldlab}   desp="Label for Field Lability" path="/gitp0/liafldlab" />
							</Col>
						</Row>
					</Col>
				</Row>

                {/* 第8行 */}
				<Row>
                    {/* 第8行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Reason of Cancelation" trn="getcan" />
							</Col>
							<Col span={14}>
                                <SelectItem InputProps={bind("purcan")} code={CodeTable.purcan}  desp="Reason of Cancelation" path="/gidgrp/rec/purcan"/>
							</Col>
						</Row>
					</Col>
                    {/* 第8行第2列 */}
					<Col span={12}>
						<Row className="row">
                            <Col span={5} offset={2}>
								<Label itext="Authentication" trn="getcan" />
							</Col>
							<Col span={14}>
                                <SelectItem InputProps={bind("autflg")} code={CodeTable.autflg}  desp="Authentication" path="/autflg"/>
							</Col>
						</Row>
					</Col>
				</Row>

                {/* 第9行 */}
				<Row>
                    {/* 第9行第1列 */}
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="New Reference" trn="getcan" />
							</Col>
							<Col span={12}>
                                <InputItem InputProps={bind("newref")}  maxLength={16}  desp="New Reference" path="/newref" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Close Flag" trn="getcan" />
							</Col>
						
							<Col span={1} >
                                <CheckboxItem InputProps={bind("mtabut_clsflg")}  desp="Close Flag" path="/mtabut/clsflg" />
							</Col>						
						</Row>
					</Col>
					
				</Row>

				{/* 底部按钮 */}
				<BottomBtn _this={this} />
				
            </div>
		</Card>
        )
 
	}
}
