import React, { Component, Fragment } from 'react'
import {
    Page, Validator, Notification, FormItem, BottomBtn,
    InputItem, Input, Bind, SelectItem, Button, Label, DatePickerItem, Section, ConfirmButton, Steps, CheckboxItem, TextAreaItem, Table
} from '@/components/Common-Library'
import Api from '@/service/api'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Row, Col, Popconfirm, Modal, Spin } from 'antd';
import { Link, withRouter } from 'react-router-dom'
import Business from '@/views/Public/Business'

const { Pre, Next, StepWrapper } = Steps
const CodeTable = CodeTableFactory.getInstance()
const confirm = Modal.confirm


@withRouter
@inject('UserContext')
@inject('i18n')
@observer
export default class BasicScreen extends Page {
    @observable
    formBlur = false

    constructor(props) {
        super(props)
        this.model = props.model
        this.bind = Bind.bind(this)
    }


    //交易内实现
    renderPage() {
        const bind = this.bind
        const { i18n } = this.props

        return (
            <div style={{ position: 'relative' }}>
                <Business  wrappedComponentRef={ref => (this.com = ref)} page={this} steps={this.props.steps} extra={this.props.extra}  model={this.model} />
                {/* 第一行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Reference" trn="getfee" />
                            </Col>
                            <Col span={14}>
                            <InputItem InputProps={bind("ownref")} disabled={true}  maxLength={16}  desp="Reference" path="/gidgrp/rec/ownref" />
                            </Col>
                     
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/* 概要描述 */}
                                <Label itext="Name" trn="getfee" />
                            </Col>
                            <Col span={14}>
                            <InputItem InputProps={bind("nam")} disabled={true} maxLength={40}  desp="Externally Displayed Name to Identify the Contract" path="/gidgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>

                </Row>
                {/* 第二行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* 信用证金额 */}
                                <Label itext="Guarantee Amount" trn="getfee" />
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("max_cur")} disabled={true} maxLength={3}  desp="Currency" path="/gidgrp/cbs/max/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("max_amt")} disabled={true}  desp="Balance" path="/gidgrp/cbs/max/amt" />
                            </Col>
                        </Row>

                    </Col>
                    <Col span={12}>
                        <Col span={5} offset={2}>
                            {/* 申请人名称 */}
                            <Label itext="Applicant" trn="getfee" />	
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("pts1_nam")} disabled={true} maxLength={100}  desp="客户英文名称" path="/gidgrp/apl/pts/nam" />
                        </Col>

                    </Col>

                </Row>
                {/* 第三行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* 未到单金额*/}
                                <Label itext="Open Amount" trn="getfee" />
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("opn1_cur")} disabled={true} maxLength={3}  desp="Currency" path="/gidgrp/cbs/opn1/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                {/* <InputItem InputProps={bind("opn1_amt")} disabled={true} /> */}
                                <InputItem InputProps={bind("opn1_amt")}  disabled={true} desp="Balance" path="/gidgrp/cbs/opn1/amt" />
                            </Col>

                        </Row>
                    </Col>

                    <Col span={12}>

                        <Col span={5} offset={2}>
                            {/* 受益人名称 */}
                            <Label itext="Beneficiary" trn="getfee" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("pts2_nam")} disabled={true} maxLength={100}  desp="客户英文名称" path="/gidgrp/ben/pts/nam" />
                        </Col>
                    </Col>
                </Row >
                {/* 第四行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                <Label itext="Handling Type" trn="getfee" />	
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("hndtyp")} disabled={true}  code={CodeTable.hndtyp}  desp="Handling Type" path="/gidgrp/rec/hndtyp"/>
                            </Col>

                        </Row>
                    </Col>

                    <Col span={12}>

                        <Col span={5} offset={2}>
                            <Label itext="Adv\Rcv Bank" trn="getfee" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("pts_nam")} disabled={true} maxLength={100}  desp="客户英文名称" path="/gidgrp/adv/pts/nam" />
                        </Col>
                    </Col>
                </Row >
                {/* 第五行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>

                            <Col span={5} offset={2}>
                                {/* 保函对付方式 */}
                                <Label itext="Type of Undertaking" trn="getfee" />
                            </Col>
                            <Col span={7}>
                                <SelectItem InputProps={bind("gartyp")} disabled={true} code={CodeTable.typgar}  desp="Type of Undertaking" path="/gidgrp/rec/gartyp"/>
                            </Col>



                        </Row>
                    </Col>
                    <Col span={12}>
                        <Col span={5} offset={2}>
                            {/* 开证行 */}
                            <Label itext="Issuing Bank" trn="getfee" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("pts3_nam")} disabled={true} maxLength={100}  desp="客户英文名称" path="/gidgrp/iss/pts/nam" />
                        </Col>

                    </Col>
                </Row>

                {/* 第六行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                <Label value={"Valid until"}   desp="Label for Field Validity" path="/gitp0/expfldlab" />
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("expdat")} disabled={true} desp="Valid until" path="/gidgrp/rec/expdat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                <Label value={"Liability until"}   desp="Label for Field Lability" path="/gitp0/liafldlab" />
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("liadat")} disabled={true} desp="Liability until" path="/gidgrp/rec/liadat" />
                            </Col>
                        </Row>
                    </Col>
                </Row>

               
                {/* 第八行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* <Label itext="Internal Transfer Y/N" trn="getfee" /> */}
                                <Label itext="I T Y/N" trn="getfee" />
                            </Col>
                            <Col span={1} >
                                <CheckboxItem InputProps={bind("intmbu_umbflg")} disabled={true}  desp="Internal Transfer Y/N" path="/xxtfee/intmbu/umbflg" ></CheckboxItem>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                <Label itext="Business Sector" trn="getfee" />
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={"Rebooking"} disabled={true} code={CodeTable.bustxt}  desp="Business Sector" path="/xxtfee/intmbu/othbussec"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>

                

                {/* 底部按钮 */}
                <BottomBtn _this={this} />
            </div >
        )
    }
}
