import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mGitrop from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import {Row ,Col} from 'antd'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class GitropScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'gitrop'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mGitrop()    
        this.bind = Bind.bind(this)
    }
	
    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div style={{ position: 'relative' }}>
	            <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Reference" trn="gitrop" />    
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/gidgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Name" trn="gitrop" /> 
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("nam")}  maxLength={40}  desp="Externally Displayed Name to Identify the Contract" path="/gidgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                            	{/* <Label itext="Applicant" trn="gitrop" />	 */}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Guarantee Amount" trn="gitrop" /> 
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("max_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/max/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("max_amt")}   desp="Balance" path="/gidgrp/cbs/max/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="客户英文名称" trn="gitrop" />
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/apl/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                            	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Open Amount" trn="gitrop" />  
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/opn1/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/gidgrp/cbs/opn1/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Handling Type" trn="gitrop" />    
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("hndtyp")} code={CodeTable.hndtyp}  desp="Handling Type" path="/gidgrp/rec/hndtyp"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
				<Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="客户英文名称" trn="gitrop" />  
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/ben/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
							<Col span={5} offset={2}>
                                <Label itext="Type of Undertaking" trn="gitrop" />  
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("gartyp")} code={CodeTable.typgar}  desp="Type of Undertaking" path="/gidgrp/rec/gartyp"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                            	{/* <Label itext="Beneficiary" trn="gitrop" />
                            	<Label itext="Adv\Rcv Bank" trn="gitrop" />	 */}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="客户英文名称" trn="gitrop" />  
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/adv/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Valid until" trn="gitrop" />
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("expdat")}  desp="Valid until" path="/gidgrp/rec/expdat" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Liability until" trn="gitrop" /> 
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("liadat")}  desp="Liability until" path="/gidgrp/rec/liadat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
							<Col span={5} offset={2}>
                                <Label itext="客户英文名称" trn="gitrop" /> 
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts3_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/iss/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row> 
                            	{/* <Label value={this.model.gitp0_liafldlab}   desp="Label for Field Lability" path="/gitp0/liafldlab" /> */}
                {/* 底部按钮 */}
                <BottomBtn _this={this} />  
		</div>
		)
	}
}
