import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mInfgid from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class InfgidScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'infgid'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mInfgid()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('infgid/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }



    //按钮事件
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">

	
	<Label itext="Own Reference" trn="infgid" />	
	<InputItem InputProps={bind("infcon_seaownref")}  maxLength={16}  desp="Own Reference for search" path="/infcon/seaownref" />

	
	<Label itext="Name" trn="infgid" />	
	<InputItem InputProps={bind("infcon_nam")}  maxLength={40}  desp="Name" path="/infcon/nam" />
	<Button  type="primary"  onClick={this.onInfbut_searow} desp="Search" path="/infbut/searow">
		<Label   itext="&Search"/>
	</Button>

	
	<Label itext="Party Reference" trn="infgid" />	
	<InputItem InputProps={bind("infcon_searef")}  maxLength={16}  desp="External Reference for search" path="/infcon/searef" />

	
	<Label itext="Role" trn="infgid" />	
	<SelectItem InputProps={bind("infcon_searol")}   desp="Role" path="/infcon/searol"/>
	<Button  type="primary"  onClick={this.onInfbut_dsp} desp="Display" path="/infbut/dsp">
		<Label   itext="D&isplay"/>
	</Button>

	
	<Label itext="Select Single Party" trn="infgid" />	
	<InputItem InputProps={bind("pty_extkey")}  maxLength={16}  desp="客户号" path="/infcon/pty/extkey" />

	
	<Label itext="Status" trn="infgid" />	
	<SelectItem InputProps={bind("infcon_seasta")} code={CodeTable.seasta}  desp="Status" path="/infcon/seasta"/>
	<Button  type="primary"  onClick={this.onInfbut_userow} desp="Use" path="/infbut/userow">
		<Label   itext="&Use"/>
	</Button>

	
	<Label itext="Party Name/BIC" trn="infgid" />	
	<InputItem InputProps={bind("infcon_seapty")}  maxLength={24}  desp="Party Name/BIC" path="/infcon/seapty" />

	
	<Label itext="Currency" trn="infgid" />	
	<SelectItem InputProps={bind("infcon_seacur")}   desp="Currency" path="/infcon/seacur"/>
	<Button  type="primary"  onClick={this.onInfbut_clr} desp="Clear" path="/infbut/clr">
		<Label   itext="&Clear"/>
	</Button>

	
	<Label itext="Opening between" trn="infgid" />	
	<DatePickerItem InputProps={bind("infcon_opndatfrom")}  desp="Open Date from" path="/infcon/opndatfrom" />

	
	<Label itext="and" trn="infgid" />	
	<DatePickerItem InputProps={bind("infcon_opndatto")}  desp="Open Date to" path="/infcon/opndatto" />

	
	<Label itext="Amount between" trn="infgid" />	
	<InputItem InputProps={bind("infcon_seaamtfr")}   desp="Amount from" path="/infcon/seaamtfr" />

	
	<Label itext="and" trn="infgid" />	
	<InputItem InputProps={bind("infcon_seaamtto")}   desp="Amount to" path="/infcon/seaamtto" />
	<SelectItem InputProps={bind("seagtyp")}   desp="Undertaking Type" path="/seagtyp"/>

	
	<Label itext="Undertaking Type" trn="infgid" />	
	<InputItem InputProps={bind("infbut_dspstm")}   desp="display stream" path="/infbut/dspstm" />
	<Button  type="primary"  onClick={this.onInfbut_exi} desp="Exit" path="/infbut/exi">
		<Label   itext="E&xit"/>
	</Button>
		</div>
		)
	}
}
