import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mLitdla from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import { Row, Col} from 'antd';
import Ptspta2 from '@/views/Public/Ptspta2'
import Business from '@/views/Public/Business'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class LitdlaScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'litdla'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLitdla()    
        this.bind = Bind.bind(this)
    }
	
	
    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div style={{ position: 'relative' }}>
                <Business wrappedComponentRef={ref => (this.com = ref)} steps={this.props.steps} extra={this.props.extra} model={this.model} />
                {/*第一行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="参考号" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="摘要" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="申请人" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/apl/pts/ref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="信用证金额" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="客户英文名称" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/apl/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="信用证余额" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("opn1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/opn1/cur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="指定银行" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("lidgrp_avbnam")}  maxLength={40}  desp="Available with Bank" path="/lidgrp/avbnam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="受益人" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts4_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ben/pts/ref" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="客户英文名称" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts4_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/ben/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="by" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("avbby")}   desp="Available by" path="/lidgrp/rec/avbby"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="开证日期" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="最迟装运日期" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="通知行" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/adv/pts/ref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="到期日/到期地点" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Place of Expiry" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="客户英文名称" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/adv/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="信用证类型" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("lcrtyp")}   desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Amount Amend History List:" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <Label itext="次修改（减额）" trn="litdla" />	
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="参考号" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="摘要" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="修改日期" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("swiadd_amedat")}  desp="Date of Amendment" path="/litdlap/swiadd/amedat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="修改次数" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("swiadd_amenbr")}   desp="Number of Amendment" path="/litdlap/swiadd/amenbr" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="实际修改次数" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("litdlap_amenbr")}   desp="Number of Amendment" path="/litdlap/amenbr" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Nominal Amount" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("nom11_amt")}   desp="Balance" path="/oldlidgrp/cbs/nom1/amt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="溢短装" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("nomtop1")}   desp="Amount Tolerance - Positive" path="/oldlidgrp/rec/nomtop" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("nomton1")}   desp="Amount Tolerance - Negative" path="/oldlidgrp/rec/nomton" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="信用证金额" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("swiadd_newnomtop")}   desp="New positive tolerance" path="/litdlap/swiadd/newnomtop" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("swiadd_newnomton")}   desp="New negative tolerance" path="/litdlap/swiadd/newnomton" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="最大金额" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("max1_cur")}  maxLength={3}  desp="Currency" path="/oldlidgrp/cbs/max/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("max1_amt")}   desp="Balance" path="/oldlidgrp/cbs/max/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="增减金额" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("swiadd_amecur")} code={CodeTable.curtxt}  desp="Currency of amended amount" path="/litdlap/swiadd/amecur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("swiadd_ameamt")}   desp="Amended Amount" path="/litdlap/swiadd/ameamt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="修改总金额" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("litdlap_engcur")}   desp="Engagement Currency" path="/litdlap/engcur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("litdlap_engamt")}   desp="change of engagement:" path="/litdlap/engamt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="修改后金额" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("swiadd_newcur")}   desp="Currency of new amount" path="/litdlap/swiadd/newcur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("swiadd_newamt")}   desp="New amount" path="/litdlap/swiadd/newamt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Maximum Amount" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("litdlap_maxcur")}  maxLength={3}  desp="Currency of Maximum Amount" path="/litdlap/maxcur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("litdlap_maxamt")}   desp="New Maximum Amount" path="/litdlap/maxamt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="金额说明" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("swiadd_nomspc")} code={CodeTable.nomspc}  desp="Amount Specification" path="/litdlap/swiadd/nomspc"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="到期日" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("expdat1")}  desp="Date of Expiry" path="/oldlidgrp/rec/expdat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="装运日" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("shpdat1")}  desp="Shipment Date" path="/oldlidgrp/rec/shpdat" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="新到期日" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("swiadd_newexpdat")}  desp="New Expiry Date" path="/litdlap/swiadd/newexpdat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="新装运日" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("swiadd_newshpdat")}  desp="New Shipmentdate" path="/litdlap/swiadd/newshpdat" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="装船期限" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <TextAreaItem InputProps={bind("swiadd_shpper")} desp="Shipment Period" path="/litdlap/swiadd/shpper"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="货物起运地" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("swiadd_shpfro")}  maxLength={65}  desp="Shipment from" path="/litdlap/swiadd/shpfro" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="始发（航空）站" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("swiadd_porloa")}  maxLength={65}  desp="Port of Loading" path="/litdlap/swiadd/porloa" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="终点（航空）站" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("swiadd_pordis")}  maxLength={65}  desp="Port of Discharge" path="/litdlap/swiadd/pordis" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="目的地" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("swiadd_shpto")}  maxLength={65}  desp="For Transportation to" path="/litdlap/swiadd/shpto" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="附加金额修改描述" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <TextAreaItem InputProps={bind("swiadd_addamtcov")} desp="Additional Amount Covered" path="/litdlap/swiadd/addamtcov"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Add. Amount" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp/aamp/aammod/addamtflg" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Additional Amount" trn="litdla" />	
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("max2_cur")}  maxLength={3}  desp="Currency" path="/lidgrp/cbs/max2/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("swiadd_addamt")}   desp="Additional Amount" path="/litdlap/swiadd/addamt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Request of Amendment" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("litdlap_ramrol")}   desp="Request of Amendment send to" path="/litdlap/ramrol"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Create Amendment Message" trn="litdla" />	
                            </Col>
                            <Col span={14}>
                                <CheckboxItem InputProps={bind("litdlap_cre707flg")}  desp="Create Amendment Message" path="/litdlap/cre707flg" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <BottomBtn _this={this} />
                                {/* <Label value={this.model.litdlap_ramrollab}   desp="Label for RAMROL" path="/litdlap/ramrollab" /> */}
                                
		</div>
		)
	}
}
